@@ -271,7 +271,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="id/text/sbasic/shared/03070400.html">"/" Operator</a></li>\
     <li><a target="_top" href="id/text/sbasic/shared/03070500.html">"^" Operator</a></li>\
 			</ul></li>\
-    <li><input type="checkbox" id="070205"><label for="070205">Pustaka Dasar Lanjutan</label><ul>\
+    <li><input type="checkbox" id="070205"><label for="070205">Perpustakaan Dasar Lanjutan</label><ul>\
     <li><a target="_top" href="id/text/sbasic/shared/03/lib_tools.html">Tools Library</a></li>\
     <li><a target="_top" href="id/text/sbasic/shared/03/lib_depot.html">DEPOT Library</a></li>\
     <li><a target="_top" href="id/text/sbasic/shared/03/lib_euro.html">EURO Library</a></li>\
@@ -675,7 +675,7 @@ document.getElementById("Contents").innerHTML='\
     <li><a target="_top" href="id/text/shared/guide/data_enter_sql.html">Executing SQL Commands</a></li>\
 		</ul></li>\
 	</ul></li></ul>\
-    <ul><li><input type="checkbox" id="04"><label for="04">Presentasi dan Menggambar</label><ul>\
+    <ul><li><input type="checkbox" id="04"><label for="04">Presentasi dan Gambar</label><ul>\
     <li><input type="checkbox" id="0401"><label for="0401">Informasi Umum dan Penggunaan Antar Muka Pengguna</label><ul>\
     <li><a target="_top" href="id/text/simpress/main0000.html">Selamat datang di Bantuan LibreOffice Impress</a></li>\
     <li><a target="_top" href="id/text/sdraw/main0000.html">Selamat datang di Bantuan LibreOffice Draw</a></li>\
